<?php

namespace App\Finance\Services;

use App\Finance\Repositories\Contracts\InvoiceRecordRepository;
use App\Finance\Repositories\Eloquent\RhawnInvoiceItemsRepositoryEloquent;
use App\Finance\Repositories\Eloquent\RhawnInvoiceRepositoryEloquent;
use App\Finance\Services\Api\BaiwangApiService;
use App\Mailer\MailService;
use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\ThirdPlatform\PlatformBaseService;
use App\Support\Facades\SimpleLogs;
use App\Support\Traits\Helpers;
use Illuminate\Support\Facades\Storage;

class InvoiceService
{
    use Helpers;

    public function __construct(InvoiceRecordRepository $invoiceRecordRepository)
    {
        $this->apiService = (new BaiwangApiService(app(ThirdApiPlatformRepository::class)));
        $this->rhawnInvoiceRepository = app(RhawnInvoiceRepositoryEloquent::class);
        $this->rhawnInvoiceItemsRepository = app(RhawnInvoiceItemsRepositoryEloquent::class);
        $this->invoiceRecordRepository = $invoiceRecordRepository;
        $this->mailService = app(MailService::class);
    }

    /**
     * 注册平台信息
     * @param string $platformName
     */
    public function registerPlatform($platformName = 'baiwang')
    {
        if('baiwang' == $platformName){
            $registerInfo = [
                'platform_name' => 'baiwang_invoice',
                'platform_title' => '百旺开票',
                'platform_url' => 'http://api.baiwangjs.com/bwdpzx/agentinvoiceservice-cloud/agentiscloud',
                'platform_desc' => '百旺开票对接',
                'platform_params' => [
                    'test_url' => 'http://dlkp.kjgc.htjs.net/agentiscloud',
                    'rhawn' => [
                        'qyid' => '23020214385104316',
                        'nsrsbh' => '91310120MA1HMP790Y',
                        'nsrmc' => '上海易恩化学技术有限公司',
                        'nsrdz' => '上海市奉贤区银工路28号E幢',
                        'nsrdh' => '021-57461626',
                        'nsryh' => '交行上海南桥支行',
                        'nsrzh' => '310069309018800003232',
                        'key' => '4hCGzt6uETEBIDVpdxtT25lM',
                        'secret' => '6x5KNgZmu9fHI2o1Ni5ecfI7y2L6JJ',
                        'tax_rate' => '13'
                    ],
                    'bhua' => [
                        'qyid' => '',
                        'nsrsbh' => '91310115312498004F',
                        'nsrmc' => '上海百舜生物科技有限公司',
                        'nsrdz' => '上海市奉贤区联合北路215号第3幢1242室 ',
                        'nsrdh' => '021-37581181',
                        'nsryh' => '交行上海大场支行',
                        'nsrzh' => '310065060018010017377',
                        'key' => '',
                        'secret' => '',
                        'tax_rate' => '13'
                    ]
                ],
                'platform_type' => 'third',
            ];
        }

        app(PlatformBaseService::class)->registerPlatform($registerInfo);
    }

    /**
     * 申请开票（包括蓝字和红字）
     * @param $invoiceParams
     */
    public function applyInvoice($invoiceParams)
    {
        if(!isset($invoiceParams['invoice_platform']) || empty($invoiceParams['invoice_platform'])){
            throw new \Exception('开票平台不存在',502);
        }
        if(!in_array($invoiceParams['invoice_platform'],['rhawn','bhua'])){
            throw new \Exception('开票平台不在允许范围内',502);
        }

        if(!isset($invoiceParams['invoice_type']) || empty($invoiceParams['invoice_type'])){
            throw new \Exception('开票类型不存在',502);
        }

        if(!in_array($invoiceParams['invoice_type'],['blue','red'])){
            throw new \Exception('开票类型错误',502);
        }

        if(!isset($invoiceParams['invoice_category'])){
            throw new \Exception('开票种类不存在',502);
        }

        if(!in_array($invoiceParams['invoice_category'],['1','2'])){
            throw new \Exception('开票种类错误',502);
        }

        if(!isset($invoiceParams['invoice_customer']) || empty($invoiceParams['invoice_customer'])){
            throw new \Exception('购买方发票信息不存在',502);
        }

        //设置发票平台
        $this->apiService->setInvoicePlatform($invoiceParams['invoice_platform']);

        //查询是否存在发票记录
        $invoiceInfo = null;
        switch($invoiceParams['invoice_platform']){
            case 'rhawn' : $invoiceInfo = $this->rhawnInvoiceRepository->getInvoiceById($invoiceParams['invoice_platform_id']);
                break;
        }
        if(!$invoiceInfo){
            $errorMessage = $invoiceParams['invoice_platform'].' invoice_platform_id ：'.$invoiceParams['invoice_platform_id'].' 没有找到相应的开票信息';
            SimpleLogs::writeLog($errorMessage, __CLASS__.':'.__FUNCTION__, 'error');
            throw new \Exception('没有找到相应的开票信息',502);
        }

        //对发票项进行检查
        /*if(!empty($invoiceParams['invoice_items'])){
            $itemIds = [];
            $invoiceItemsParams = [];
            foreach($invoiceParams['invoice_items'] as $item){
                $invoiceItemsParams[$item['item_id']] = $item;
                array_push($itemIds,$item['item_id']);
            }
            //查询产品是否存在
            $invoiceItem = $this->rhawnInvoiceItemsRepository->getInvoiceItemsByIdAndItemId($invoiceParams['invoice_platform_id'],$itemIds);
            if($invoiceItem){
                foreach($invoiceItem as $item){
                    if(isset($invoiceItemsParams[$item['soid_id']])){
                        if($invoiceItemsParams[$item['soid_id']]['item_nums'] > $item['dpd_num']){
                            SimpleLogs::writeLog('item_id : '.$item['soid_id'].' 开票数量超出已发货数量', __CLASS__.':'.__FUNCTION__, 'error');
                            throw new \Exception('开票数量超出已发货数量',502);
                        }
                    }
                }
            }
        }*/

        $invoiceNumber = 'I';
        $invoiceNumber .= $invoiceParams['invoice_platform'] == 'rhawn' ? 'R' : 'B';
        $invoiceNumber .= $invoiceParams['invoice_type'] == 'blue' ? 'B' : 'R';
        $invoiceNumber .= $invoiceParams['invoice_category'] . date('Ymd',time()).strtoupper($this->randomFromDevice(5));

        $platformInfo = $this->apiService->getPlatformInfo()['platform_params'][$invoiceParams['invoice_platform']];

        //组装请求参数
        $applyInvoiceParams = [];
        $applyInvoiceParams['qyId'] = $platformInfo['qyid'];
        $applyInvoiceParams['sksbh'] = $platformInfo['nsrsbh'];
        $applyInvoiceParams['bmbBbh'] = '';
        $applyInvoiceParams['ddlsh'] = $invoiceNumber;
        $applyInvoiceParams['fplxdm'] = $invoiceParams['invoice_category'] == '2' ? '01' : '02';
        $applyInvoiceParams['kplx'] = $invoiceParams['invoice_type'] == 'blue' ? 0 : 1;
        $applyInvoiceParams['tspz'] = '';
        $applyInvoiceParams['zsfs'] = 0;
        $applyInvoiceParams['qdbz'] = count($invoiceParams['invoice_items']) > 8 ? 1 : 0;
        $applyInvoiceParams['xsfMc'] = $platformInfo['nsrmc']; // 销售方名称
        $applyInvoiceParams['xsfNsrsbh'] = $platformInfo['nsrsbh']; //销售方纳税人识别号
        $applyInvoiceParams['xsfDz'] = $platformInfo['nsrdz']; // 销售方地址
        $applyInvoiceParams['xsfDh'] = $platformInfo['nsrdh']; // 销售方电话
        $applyInvoiceParams['xsfYh'] = $platformInfo['nsryh']; // 销售方银行名称
        $applyInvoiceParams['xsfZh'] = $platformInfo['nsrzh']; // 销售方银行账户
        $applyInvoiceParams['gmfMc'] = $invoiceParams['invoice_customer']['cust_name']; // 购买方名称
        $applyInvoiceParams['gmfNsrsbh'] = $invoiceParams['invoice_customer']['cust_code']; // 购买方纳税人识别号
        $applyInvoiceParams['gmfDz'] = $invoiceParams['invoice_customer']['cust_address']; // 购买方地址
        $applyInvoiceParams['gmfDh'] = $invoiceParams['invoice_customer']['cust_phone']; // 购买方电话
        $applyInvoiceParams['gmfYh'] = $invoiceParams['invoice_customer']['cust_bankname']; // 购买方银行名称
        $applyInvoiceParams['gmfZh'] = $invoiceParams['invoice_customer']['cust_bankaccount']; // 购买方银行账户
        $applyInvoiceParams['gmfMobile'] = $invoiceParams['invoice_customer']['cust_mobile']; // 购买方银行账户
        $applyInvoiceParams['gmfEmail'] = $invoiceParams['invoice_customer']['cust_email']; // 购买方邮箱

        $applyInvoiceParams['sqr'] = $invoiceParams['invoice_creater_by'];
        $applyInvoiceParams['kpr'] = $invoiceParams['invoice_creater_by'];
        $applyInvoiceParams['dlzh'] = $platformInfo['nsrsbh'];
        $applyInvoiceParams['sfwzzfp'] = 'N';
        $applyInvoiceParams['zpFppzdm'] = $invoiceParams['invoice_category'] == 2 ? '1130' : '04';
        $applyInvoiceParams['jshj'] = bcmul($invoiceParams['invoice_money'],1,2);
        $applyInvoiceParams['hjje'] = bcdiv($applyInvoiceParams['jshj'],1.13,2);
        $applyInvoiceParams['hjse'] = bcsub($applyInvoiceParams['jshj'],$applyInvoiceParams['hjje'],2);//bcmul($applyInvoiceParams['hjje'],bcdiv($platformInfo['tax_rate'],100,3),2);

        //初始化非必填项
        $applyInvoiceParams['bz'] = '';
        $applyInvoiceParams['kce'] = '';
        $applyInvoiceParams['sslkjly'] = '';

        $applyInvoiceParams['detailParam'] = [];
        //开票明细列
        foreach($invoiceParams['invoice_items'] as $item){
            $applyInvoiceItems = [];
            $applyInvoiceItems['fphxz'] = 0;
            $applyInvoiceItems['hsbz'] = 1; //默认含税
            $applyInvoiceItems['spmc'] = $item['item_name'];
            $applyInvoiceItems['spbm'] = '1070214010000000000';//$item['p_code'];
            $applyInvoiceItems['ggxh'] = $item['item_spec'];
            $applyInvoiceItems['dw'] = 'EA';
            $applyInvoiceItems['je'] = bcmul($item['item_price'],1,2);
            $applyInvoiceItems['sl'] = $item['item_nums'];
            $applyInvoiceItems['dj'] = bcdiv($applyInvoiceItems['je'],$applyInvoiceItems['sl'],2);
            $applyInvoiceItems['se'] = '';
            $applyInvoiceItems['slv'] = bcdiv($platformInfo['tax_rate'],100,3);
            $applyInvoiceItems['lslbs'] = 0;
            $applyInvoiceItems['yhzcbs'] = 0;
            $applyInvoiceItems['zxbm'] = '';
            $applyInvoiceItems['zzstsgl'] = '';
            array_push($applyInvoiceParams['detailParam'],$applyInvoiceItems);
        }

        //请求接口之前记录开票信息
        $invoiceParams = array_merge($invoiceParams,['invoice_number' => $invoiceNumber]);
        $result = $this->saveInvoiceRecord($invoiceParams);
        if($result){
            //记录请求参数
            $this->apiService->storePlatformDataEntries('invoice_apply_'.$result['invoice_number'],$applyInvoiceParams);
            $response = $this->apiService->applyElecInvoice($applyInvoiceParams);
            if($response){
                $this->invoiceRecordRepository->saveInvoice([
                    'invoice_number' => $result['invoice_number'],
                    'invoice_status' => 0
                ]);
                return true;
            }
        }

        throw new \Exception('申请发票失败',502);
    }

    public function cancelBlueInvoice()
    {
        if(!isset($invoiceParams['invoice_platform']) || empty($invoiceParams['invoice_platform'])){
            throw new \Exception('开票平台不存在',502);
        }
        if(!isset($invoiceParams['invoice_real_number']) || empty($invoiceParams['invoice_real_number'])){
            throw new \Exception('发票号码不存在',502);
        }

        if(!isset($invoiceParams['invoice_cancel_by']) || empty($invoiceParams['invoice_cancel_by'])){
            throw new \Exception('发票作废人不存在',502);
        }

        if(!isset($invoiceParams['invoice_platform']) || empty($invoiceParams['invoice_platform'])){
            throw new \Exception('开票平台不存在',502);
        }
        if(!in_array($invoiceParams['invoice_platform'],['rhawn','bhua'])){
            throw new \Exception('开票平台不在允许范围内',502);
        }

        //设置发票平台
        $this->apiService->setInvoicePlatform($invoiceParams['invoice_platform']);

        //查询发票号码对应的数据
        $invoiceInfo = $this->invoiceRecordRepository->getInvoiceRecordByRealNumber($invoiceParams['invoice_real_number']);
        if(!$invoiceInfo){
            throw new \Exception('发票数据不存在',502);
        }

        if($invoiceInfo['invoice_status'] != 1){
            throw new \Exception('该发票不是确认状态,无法作废',502);
        }

        $platformInfo = $this->apiService->getPlatformInfo()['platform_params'][$invoiceParams['invoice_platform']];

        $cancelInvoiceParams = [];
        $cancelInvoiceParams['qyId'] = $platformInfo['qyid'];
        $cancelInvoiceParams['ddlsh'] = $invoiceInfo['invoice_number'];
        $cancelInvoiceParams['dlzh'] = $platformInfo['nsrsbh'];
        $cancelInvoiceParams['zfr'] = $invoiceParams['invoice_real_number'];

        //记录请求参数
        $this->apiService->storePlatformDataEntries('invoice_cancel_'.$invoiceInfo['invoice_number'].'_'.$invoiceInfo['invoice_real_number'],$cancelInvoiceParams);
        $response = $this->apiService->cancelElecInvoice($cancelInvoiceParams);
        if($response){
            $this->invoiceRecordRepository->saveInvoice([
                'invoice_number' => $invoiceInfo['invoice_number'],
                'invoice_status' => 2
            ]);
            return true;
        }
        throw new \Exception('发票作废失败',502);
    }

    public function confirmRedInvoice()
    {

    }

    public function cancelRedInvoice()
    {

    }

    public function downloadInvioce($invoiceNumber)
    {

    }

    public function queryInvoiceInfo($invoiceParams)
    {
        //设置发票平台
        $this->apiService->setInvoicePlatform($invoiceParams['invoice_platform']);

        $cancelInvoiceParams = [];
        $cancelInvoiceParams['ddlsh'] = $invoiceParams['invoice_number'];

        //记录请求参数
        $response = $this->apiService->queryOrder($cancelInvoiceParams);
        return $response;
    }

    public function getQiyeInvoiceInfo()
    {
        //设置发票平台
        $info = $this->apiService->queryQiyeUniqueSign('rhawn');
        var_dump($info);
    }

    /**
     * 保存开票记录
     * @param $params
     */
    public function saveInvoiceRecord($invoiceParams)
    {
        $saveParams = [];
        try{
            $invoiceInfo = $this->invoiceRecordRepository->getInvoiceRecordByNumber($invoiceParams['invoice_number']);
            if(!$invoiceInfo){
                $saveParams['invoice_number'] = $invoiceParams['invoice_number'];
                $saveParams['invoice_type'] = $invoiceParams['invoice_type'] == 'blue' ? 1 : 2;
                $saveParams['invoice_status'] = -1;
                $saveParams['invoice_money'] = $invoiceParams['invoice_money'];
                $saveParams['invoice_platform'] = $invoiceParams['invoice_platform'];
                $saveParams['platform_invoice_id'] = $invoiceParams['invoice_platform_id'];
                $saveParams['invoice_creater_by'] = $invoiceParams['invoice_creater_by'];
                $saveParams['invoice_category'] = $invoiceParams['invoice_category'];
                $saveParams['invoice_items'] = json_encode($invoiceParams['invoice_items'],JSON_UNESCAPED_UNICODE);
                $saveParams['invoice_customer'] = json_encode($invoiceParams['invoice_customer'],JSON_UNESCAPED_UNICODE);
            }else{
                $saveParams = current($invoiceInfo);

                if(isset($invoiceParams['invoice_type']) && !empty($invoiceParams['invoice_type'])){
                    $saveParams['invoice_type'] = $invoiceParams['invoice_type'] == 'blue' ? 1 : 2;
                }
                if(isset($invoiceParams['invoice_status']) && !empty($invoiceParams['invoice_status'])){
                    $saveParams['invoice_status'] = $invoiceParams['invoice_status'];
                }
                if(isset($invoiceParams['invoice_money']) && !empty($invoiceParams['invoice_money'])){
                    $saveParams['invoice_money'] = $invoiceParams['invoice_money'];
                }
                if(isset($invoiceParams['invoice_platform']) && !empty($invoiceParams['invoice_platform'])){
                    $saveParams['invoice_platform'] = $invoiceParams['invoice_platform'];
                }
                if(isset($invoiceParams['platform_invoice_id']) && !empty($invoiceParams['platform_invoice_id'])){
                    $saveParams['platform_invoice_id'] = $invoiceParams['platform_invoice_id'];
                }
                if(isset($invoiceParams['invoice_creater_by']) && !empty($invoiceParams['invoice_creater_by'])){
                    $saveParams['invoice_creater_by'] = $invoiceParams['invoice_creater_by'];
                }
                if(isset($invoiceParams['invoice_category']) && !empty($invoiceParams['invoice_category'])){
                    $saveParams['invoice_category'] = $invoiceParams['invoice_category'];
                }
                if(isset($invoiceParams['invoice_items']) && !empty($invoiceParams['invoice_items'])){
                    $saveParams['invoice_items'] = $invoiceParams['invoice_items'];
                }
                if(isset($invoiceParams['invoice_customer']) && !empty($invoiceParams['invoice_customer'])){
                    $saveParams['invoice_customer'] = $invoiceParams['invoice_customer'];
                }
            }

            $result = $this->invoiceRecordRepository->saveInvoice($saveParams);

            if($result){
                return $result;
            }
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':'.__FUNCTION__, 'error');
            return false;
        }
    }

    public function apiCallBack($params)
    {
        if(isset($params) && !empty($params)){
            $queueParams = [];
            //查询流水号是否有效
            $invoiceInfo = $this->invoiceRecordRepository->getInvoiceRecordByNumber($params['ddlsh']);
            if(!$invoiceInfo){
                //SimpleLogs::writeLog($params, __CLASS__.':'.__FUNCTION__.' 无法找到发票流水号：'.$params['ddlsh'].'的数据', 'error');
                return false;
            }

            //现将返回的数据进行存储
            switch($params['ywlxdm']){
                case 'fpkj' :
                    $this->apiService->storePlatformDataEntries('invoice_callBack_'.$params['ddlsh'].'_applyInvoice',$params);
                    $queueParams = ['params' => $params,'type' => 'applyInvoiceCallBack'];
                    break;
            }
            //塞入队列
            $this->apiService->pushQueue([
                'params' => $queueParams,
                'consumer' => __CLASS__,
                'method' => 'invoiceApiCallBack'
            ],'invoiceCallBack');
        }
        /*$values = $this->apiService->getPlatformDataEntries('invoice_callBack_IRB220230301KOOA9_applyInvoice','data_values');
        $queueParams = ['params' => $values,'type' => 'applyInvoiceCallBack'];
        $this->apiService->pushQueue([
            'params' => $queueParams,
            'consumer' => __CLASS__,
            'method' => 'invoiceApiCallBack'
        ],'invoiceCallBack');*/
    }

    public function invoiceApiCallBack($params)
    {
        if(empty($params)){
            return false;
        }
        //记录日志
        SimpleLogs::writeLog($params, __CLASS__.':'.__FUNCTION__.' callback params => ');

        //根据type回调相应方法处理逻辑
        if($params['type'] && method_exists(__CLASS__,$params['type'])){
            $func = $params['type'];
            $this->$func($params['params']);
        }
    }

    public function applyInvoiceCallBack($callBackParams)
    {
        if(empty($callBackParams)){
            return false;
        }

        //根据发票流水找到相应数据
        if(isset($callBackParams['ddlsh']) && !empty($callBackParams['ddlsh'])){
            $invoiceInfo = $this->invoiceRecordRepository->getInvoiceRecordByNumber($callBackParams['ddlsh']);
            if(!$invoiceInfo){
                SimpleLogs::writeLog($callBackParams, __CLASS__.':'.__FUNCTION__.' 无法找到发票流水号：'.$callBackParams['ddlsh'].'的数据', 'error');
                return false;
            }
            $invoiceInfo = current($invoiceInfo);
            //查询发票信息
            $invoiceResponse = $this->queryInvoiceInfo([
                'invoice_platform' => $invoiceInfo['invoice_platform'],
                'invoice_number' => $callBackParams['ddlsh']
            ]);

            //更新对应的发票数据，并反写回相应的平台发票
            try{
                $updateInvoice = [];
                $updateInvoice['invoice_number'] = $invoiceResponse['ddlsh'];
                if($callBackParams['status'] == 1 && $invoiceResponse['status'] == 2){
                    $updateInvoice['invoice_status'] = 1;
                    $updateInvoice['invoice_real_number'] = $invoiceResponse['qdfphm'];
                    $updateInvoice['invoice_real_date'] = strtotime($invoiceResponse['kprq']);
                    $updateInvoice['invoice_pdf_url'] = $invoiceResponse['pdf'];

                    $updatedInvoiceResult = $this->invoiceRecordRepository->saveInvoice($updateInvoice);
                    if($updatedInvoiceResult){
                        //对平台的发票信息进行更新
                        $updateResult = null;
                        switch($updatedInvoiceResult['invoice_platform']){
                            case 'rhawn' :
                                $updateResult = $this->rhawnInvoiceRepository->updateInvoiceById($updatedInvoiceResult['platform_invoice_id'],
                                    [
                                        'soi_api_status' => 1,
                                        'soi_no' => $updatedInvoiceResult['invoice_real_number'],
                                        'soi_date' => $updatedInvoiceResult['invoice_real_date'],
                                        //'soi_total' => bcmul($callBackParams['jshj'],1,2),
                                        'soi_tax' => bcmul($invoiceResponse['hjse'],1,2),
                                        'soi_amount' => bcmul($invoiceResponse['hjje'],1,2)
                                    ]
                                );
                        }
                        if($updateResult){
                            //获取发票地址
                            $this->sendInvoiceEmail($updatedInvoiceResult);
                        }
                    }else{
                        $updateInvoice['invoice_status'] = 2;
                        $updatedInvoiceResult = $this->invoiceRecordRepository->saveInvoice($updateInvoice);
                    }
                }
            }catch(\Throwable $exception){
                SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':'.__FUNCTION__, 'error');
            }
        }
    }

    public function sendInvoiceEmail($invoiceParams)
    {
        //获取发票地址
        if(isset($invoiceParams['invoice_pdf_url']) && !empty($invoiceParams['invoice_pdf_url'])){
            $filename = $invoiceParams['platform_invoice_id'].'_'.$invoiceParams['invoice_number'].'_'.$invoiceParams['invoice_real_date'].'.pdf';
            $path = config('filesystems.default.root').'public/finance/invoice/'.$invoiceParams['invoice_platform'].'/'.$invoiceParams['platform_invoice_id'].'/';
            if(!Storage::exists($path.$filename)){
                $pdf = $this->apiService->clientRequest('get',$invoiceParams['invoice_pdf_url'],[]);
                if($pdf){
                    Storage::put($path.$filename,$pdf);
                }
            }
        }
        //生成download发票的url
        $urlParams = [
            'platform_invoice_id' => $invoiceParams['platform_invoice_id'],
            'invoice_real_number' => $invoiceParams['invoice_real_number'],
            'invoice_real_date' => $invoiceParams['invoice_real_date']
        ];
        $token = base64_encode(hash_hmac("sha256", json_encode($urlParams), $invoiceParams['invoice_real_number'], true));
        $downloadUrl = 'http://openapi.chem-site.com/finance/invoice/download?token='.$token;

        $customerInfo = json_decode($invoiceParams['invoice_customer'],true);

        $title = $customerInfo['cust_name'].'电子发票';

        $platformName = $invoiceParams['invoice_platform'] == 'rhawn' ? '上海易恩化学技术有限公司' : '上海百舜生物科技有限公司';

        $message = '尊敬的'.$customerInfo['cust_name'].','. $platformName . '给您开具了电子发票，请查收。';
        $message .= "\r\n发票信息:\r\n";
        $message .= "\r\n开票日期: ".date('Y-m-d H:i:s',$invoiceParams['invoice_real_date'])."\r\n";
        $message .= "\r\n销方名称: ".$platformName."\r\n";
        $message .= "\r\n购方名称: ".$customerInfo['cust_name']."\r\n";
        $message .= "\r\n合计金额: ".bcmul($invoiceParams['invoice_money'],1,2)."\r\n";
        $message .= "\r\n发票号码: ".$invoiceParams['invoice_real_number']."\r\n";

        $message .= "<a href=".$downloadUrl."电子发票下载地址</a>";

        $this->mailService->sendMailToHtml($title, 'hangjun@rhawn.cn',$message);
    }

    public function getInvoicePdfDownloadUrl()
    {

    }

}
